from typing import Dict, List, Union

from com.inductiveautomation.ignition.alarming.common.rosters import RosterModel
from com.inductiveautomation.ignition.common.user import PyUser
from dev.coatl.helper.types import AnyStr

def addUsers(rosterName: AnyStr, users: List[PyUser]) -> None: ...
def createRoster(name: AnyStr, description: Union[AnyStr, None]) -> None: ...
def deleteRoster(rosterName: AnyStr) -> None: ...
def getRoster(name: AnyStr) -> RosterModel: ...
def getRosterNames() -> List[AnyStr]: ...
def getRosters() -> Dict[AnyStr, List[AnyStr]]: ...
def removeUsers(rosterName: AnyStr, users: List[PyUser]) -> None: ...
